@@ -398,13 +398,13 @@ static void tfont_setup_font(TFont* pf, const char* fname, FONTSET_HALF hf)
 	tpcf_init(&pcf);
 
 	if (access(fname, R_OK) != 0) {
-		printf("PCF : CANNOTOPEN : %s\n", fname);
+		print_message("PCF : CANNOTOPEN : %s\n", fname);
 		return;
 	}
 	if ((nf > 3 && strcmp(".gz", fname+nf-3) == 0) ||
 	    (nf > 2 && strcmp(".Z", fname+nf-2) == 0)) {
 		if (strlen(JFB_GZIP_PATH) + 10 + nf >= sizeof cmd) {
-			printf("PCF : long filename? : %s\n", fname);
+			print_message("PCF : long filename? : %s\n", fname);
 			return;
 		}
 #ifndef JFB_GZIP_PATH
@@ -421,7 +421,7 @@ static void tfont_setup_font(TFont* pf, const char* fname, FONTSET_HALF hf)
 		piped = 0;
 	}
 	if (!fp) {
-		printf("PCF : CANNOTOPEN : %s\n", fname);
+		print_message("PCF : CANNOTOPEN : %s\n", fname);
 		return;
 	}
 	tpcf_load(&pcf, fp);
